pm4py.statistics.eventually\_follows.log package
================================================

Submodules
----------

pm4py.statistics.eventually\_follows.log.get module
---------------------------------------------------

.. automodule:: pm4py.statistics.eventually_follows.log.get
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.statistics.eventually_follows.log
   :members:
   :undoc-members:
   :show-inheritance:
